
import numpy as np 

class Sorter:
	def __init__(self):
		self.x = np.array([])  
	def sort_things(self,things):
		idx = np.argsort(things) 
		return np.array(things)[idx] 


Notes = '''

S = Sorter()
things1 = [5,1,4,2,3]
things2 = S.sort_things(things1)


'''











from setuptools import setup, find_packages

setup(
    # Basic package information:
    name='rolfdog',  
    version='0.0.5',
    packages=find_packages(),  # Automatically find packages in the directory

    # Dependencies:
    install_requires=[
        'numpy>=1.1.1',  
        'pandas>=0.1.1',  
    ],

    # Metadata for PyPI:
    author          ='James A. Rolfsen',
    author_email    ='james.rolfsen@think.dev', 
	description     ='Rolfdog Rolfdog Rolfdog',
	url             ='https://github.com/jrolf/rolfdog',    # Link to your repo
    
    #long_description=open('README.md').read(),
    #long_description_content_type='text/markdown',  # If your README is in markdown

    # More classifiers: https://pypi.org/classifiers/
    classifiers=[
        'Programming Language :: Python :: 3.7', 
        'License :: OSI Approved :: MIT License',  # Ensure this matches your LICENSE file
        'Operating System :: OS Independent',
        'Natural Language :: English',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    

)









import numpy as np 

class Adder:
	def __init__(self):
		self.x = np.array([])  
	def add_things(self,things1,things2):
		a = np.array(things1)
		b = np.array(things2)
		return a+b


Notes = '''

things1 = [5,1,4,2,3]
things2 = [1,2,3,4,5] 

A = Adder()
things3 = A.add_things(things1)

'''










import numpy
import numpy as np 
import pandas as pd 

from .jtools1 import Sorter  # Assuming you have a class named Sorter in jtools1.py
from .jtools2 import Adder   # Assuming you have a class named Adder in jtools2.py
